Actions Status MetaCPAN Release

NAME

Acme::Insult::Evil - Programmatically Generate Evil Insults

SYNOPSIS

use Acme::Insult::Evil qw[insult];
say insult( ); # stringify

DESCRIPTION

Acme::Insult::Evil provides 'evil' 'insulting' statements generated by the RESTful Evil Insult Generator API.

METHODS

These functions may be imported by name or with the :all tag.

insult( [...] )

Tear someone down.

my $shade = insult( ); # Random insult
print insult( language => 'fr' ); # stringify

You may request specific insults by passing parameters.

Expected parameters include:

On success, an insult is returned as a blessed hash reference containing the following data:

LICENSE & LEGAL

Copyright (C) Sanko Robinson.

This library is free software; you can redistribute it and/or modify it under the terms found in the Artistic License 2. Other copyrights, terms, and conditions may apply to data transmitted through this module.

Insults are generated by the Evil Insult Generator.

AUTHOR

Sanko Robinson sanko@cpan.org

...but why?

I'm inflicting this upon the world because oodler577 invited me to help expand Perl's coverage of smaller open APIs. Blame them or join us in the effort.